@@ -31,8 +31,23 @@ class ProteinManager:
             self.error_status = True
         else:
             self.error_status = False
+            
+    # decorators 
+    # To be added in 0.1.6 to streamline ID
+    # checking
+    def convertIDToUpperCase(fn):
+        def wrapped(_, a):
+            return fn(_, str(a).upper())
+        return wrapped
+
+    def convertIDListToUpperCase(fn):
+        def wrapped(_, a):
+            return fn(_, [str(x).upper() for x in a])
+        return wrapped
+            
 
 
+    @convertIDToUpperCase
     def has_key(self, ID):
         """ Check if the datastore has a protein ID loaded or not. Does
             not preload the ID in question
@@ -45,18 +60,22 @@ class ProteinManager:
         """
         return self.datastore.keys()
     
+    @convertIDToUpperCase
     def get_protein_name(self, ID):
         """ Returns the name of the protein """
         return self.datastore.get_protein_name(ID)
     
+    @convertIDToUpperCase
     def get_protein_sequence(self, ID):
         """ Return the protein's primary amino acid sequence as a string """
         return self.datastore.get_sequence(ID)
 
+    @convertIDToUpperCase
     def get_raw_xml(self, ID):
         """ Return the raw XML associated with this accession value """
         return self.datastore.get_raw_xml(ID)
 
+    @convertIDToUpperCase
     def get_variants(self, ID):
         """ Return a list of dictionaries, where each dictionary is a mutation 
             dictionary with six keys - 
@@ -71,6 +90,7 @@ class ProteinManager:
             
         return self.datastore.get_variants(ID)
 
+    @convertIDToUpperCase
     def get_geneID(self, ID):
         """ Proteins are also associated with specific genes. This returns 
             the gene ID associated with this accession number. This may be 
@@ -78,12 +98,14 @@ class ProteinManager:
         """
         return self.datastore.get_geneID(ID)
 
+    @convertIDToUpperCase
     def get_gene_name(self, ID):
         """ Get the name of the gene associated with this protein. This may be empty if 
             no true gene is associated.
         """
         return self.datastore.get_gene_name(ID)
 
+    @convertIDToUpperCase
     def get_taxonomy(self, ID):
         """ Get the NCBI defined taxonomy string associated with the organism or
             origin this protein comes from. Returns an ordered list, where the order
@@ -91,6 +113,7 @@ class ProteinManager:
         """
         return self.datastore.get_taxonomy(ID)
 
+    @convertIDToUpperCase
     def get_domains(self, ID):
         """ Get a list of dictionary objects, where each dictionary refers to a
             single Pfam domain. These dictionaries have five entires each;
@@ -111,11 +134,13 @@ class ProteinManager:
         """
         return self.datastore.get_domains(ID)
 
+    @convertIDToUpperCase
     def get_species(self, ID):
         """ Returns the species from which this protein was extracted.
         """
         return self.datastore.get_species(ID)
 
+    @convertIDToUpperCase
     def get_other_accessions(self, ID):
         """ Returns a list of tuples which define ("type of accession", "value") 
             for other accessions linked to this accession value.
@@ -140,17 +165,20 @@ class ProteinManager:
                 
         return self.datastore.get_other_accessions(ID)
     
+    @convertIDToUpperCase
     def get_protein_sequence_length(self, ID):
         """ Returns an integer equal to the length of the protein's primary sequence. 
         """
         return len(self.datastore.get_sequence(ID))
 
+    @convertIDToUpperCase
     def get_ID_type(self, ID):
         """ Returns a two position list, where list[0] is an exit code 
             and list[1] is the name of the type of accession number. 
         """
         return self.datastore.get_ID_type(ID)
 
+    @convertIDToUpperCase
     def get_isoforms(self, ID):
         """ Returns a dictionary, where the keys are isoform names
             and the values are the full isoform sequences associated
@@ -163,20 +191,24 @@ class ProteinManager:
         """
         return self.datastore.get_isoforms(ID)
 
+    @convertIDToUpperCase
     def run_translation(self, Acc):
         """ Translates an alphanumeric accession number to a GI number. """
         return self.datastore.translate_Asc2GI(Acc)
 
+    @convertIDListToUpperCase
     def batch_get_protein_sequence(self, IDList):
         """ Allows for primary sequence retrieval en-masse using a list of IDs
             as input. Returns a dictionary, indexed by accession number, of
             the various sequences. Makes a single request to the NCBI server """
         return self.datastore.batchFetch(self.datastore.get_sequence, IDList)
 
+    @convertIDListToUpperCase
     def batch_get_protein_name(self, IDList):
         """ Get the names of a list of IDs """
         return self.datastore.batchFetch(self.datastore.get_protein_name, IDList)
 
+    @convertIDListToUpperCase
     def batch_get_variants(self, IDList):
         """ Allows variants retrieval en-mass using a list of IDs as input.
             Returns a dictionary of lists, where each dictionary entry is 
